pub trait Endpoint<M>: Sealed {
// Required methods
fn endpoint_location(&self) -> EndpointLocation;
fn post<C>(self, cx: &C, message: M)
where C: Actor;
}Expand description
A typed endpoint that can receive M.
This trait abstracts over local actor handles, local port handles, remote actor refs, remote port refs, and one-shot ports. It is sealed so that Hyperactor owns the post semantics for each endpoint kind.
Required Methods
Sourcefn endpoint_location(&self) -> EndpointLocation
fn endpoint_location(&self) -> EndpointLocation
The logical location of this endpoint.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.