pub trait RemoteEndpoint<M>: Endpoint<M> {
// Required method
fn post_with_headers<C>(self, cx: &C, headers: Flattrs, message: M)
where C: Actor;
}Expand description
A typed endpoint that can receive M with message headers.
RemoteEndpoint is implemented only for endpoints whose post path preserves
headers.
Required Methods
Sourcefn post_with_headers<C>(self, cx: &C, headers: Flattrs, message: M)where
C: Actor,
fn post_with_headers<C>(self, cx: &C, headers: Flattrs, message: M)where
C: Actor,
Post message and headers to this endpoint from cx.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.